==> emelfm2-0.1.2.tar.gz: emelfm2-0.1.2/src/dialogs/e2_select_dir_dialog.c <==
/* $Id$
 * 
 * Copyright (C) 2005 tooar <tooar@gmx.net>
 * 
 * This file is part of emelFM2.
 * emelFM2 is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2, or (at your option)
 * any later version.
 *
 * emelFM2 is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with emelFM2; see the file GPL. If not, contact the Free Software
 * Foundation, 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 */

#include "emelfm2.h"
#include "e2_dialog.h"

static GtkFileChooser *fchooser;
static gchar **choice;

static void _e2_opendir_dialog_ok_cb (GtkWidget *button, GtkWidget *open_dialog)
{
	gchar *dir = gtk_file_chooser_get_current_folder (fchooser);
	if (dir == NULL)
		*choice = NULL;
	else
	{
		F_DECLARE;
		gchar *utf = F_FILENAME_FROM_LOCALE (dir);
		*choice = g_strconcat (utf, G_DIR_SEPARATOR_S, NULL);
		g_free (dir);
		F_FREE (utf);
	}
	gtk_widget_destroy (open_dialog);
	open_dialog = NULL;
}
static void _e2_opendir_dialog_cancel_cb (GtkWidget *button, GtkWidget *open_dialog)
{
//	*choice = NULL;
	gtk_widget_destroy (open_dialog);
	open_dialog = NULL;
}

#if defined (E2_CURRENTGTK_VERSION) && GTK_MINOR_VERSION >= 6
//FIXME for some reason, toggling re-sensitizes the main window
static void _e2_opendir_toggle_hodden_cb (GtkWidget *button, GtkFileChooser *fchooser)
{
	gboolean nowhidden = gtk_file_chooser_get_show_hidden (fchooser);
	gtk_file_chooser_set_show_hidden (fchooser, ! nowhidden);
/* FIXME this does not change the button image
	if (nowhidden)
	{
		static GtkWidget *show;
		if (show == NULL)
			show = gtk_image_new_from_file (ICON_DIR"hidden_show_"E2IP".png");//no error check here
		gtk_button_set_image (GTK_BUTTON (button), show);
	}
	else
	{
		static GtkWidget *noshow;
		if (noshow == NULL)
			noshow = gtk_image_new_from_file (ICON_DIR"hidden_noshow_"E2IP".png");
		gtk_button_set_image (GTK_BUTTON (button), noshow);
	}
*/
}
#endif
/**
 * @brief display directory-chooser dialog
 *
 * @a newdir is set to a /-terminated string, newly-allocated,
 * or else NULL, if no or invalid choice is made
 *
 * @param currentdir utf string, path of dir to show in chooser when it opens
 * @param newdir pointer to store for chosen new dir-path
 *
 * @return
 */
void e2_opendir_dialog_create (gchar *currentdir, gchar **newdir)
{
	choice = newdir;

	static GtkWidget *open_dialog;
	//only 1 dialog at a time
	if (open_dialog != NULL)
		gtk_widget_destroy (open_dialog);

	open_dialog = gtk_dialog_new ();
	E2_DIALOG_TITLE (GTK_WINDOW (open_dialog), _("open"));

	GtkWidget *vbox = GTK_DIALOG (open_dialog)->vbox;
	gtk_container_set_border_width (GTK_CONTAINER (vbox), E2_PADDING);
	
	GtkWidget *chooser = gtk_file_chooser_widget_new
		(GTK_FILE_CHOOSER_ACTION_SELECT_FOLDER);
	gtk_box_pack_start (GTK_BOX(vbox), chooser, TRUE, TRUE, 0);

//	gtk_file_chooser_set_local_only (FALSE); FIXME vfs
/*	if (g_str_has_suffix (currentdir, G_DIR_SEPARATOR_S)
	{
		gchar *p = currentdir + strlen (currendir);
		*(p-1) = '\0';
	}
*/
	fchooser = GTK_FILE_CHOOSER (chooser);
	gtk_file_chooser_set_current_folder (fchooser, currentdir); //trailing / ok

#if defined (E2_CURRENTGTK_VERSION) && GTK_MINOR_VERSION >= 6
//	if (gtk_check_version (2, 6, 0) == NULL)
//	{
		e2_dialog_add_undefined_button_custom (open_dialog, FALSE, E2_RESPONSE_USER1,
		_("_Hidden"), ICON_DIR"hidden_show_"E2IP".png", _("Toggle display of hidden directories"), 
		_e2_opendir_toggle_hodden_cb, fchooser);
//	}
#endif
	e2_dialog_add_button_custom (open_dialog, TRUE, &E2_BUTTON_CANCEL,
		NULL, _e2_opendir_dialog_cancel_cb, open_dialog);
//	GtkWidget *button = e2_dialog_add_defined_button (open_dialog, &E2_BUTTON_CANCEL);
	e2_dialog_add_button_custom (open_dialog, FALSE, &E2_BUTTON_OK,
		NULL, _e2_opendir_dialog_ok_cb, open_dialog);

	e2_dialog_setup (open_dialog, app.main_window);
//	gtk_widget_grab_focus (button);
	e2_dialog_resize (open_dialog, 1.6);

#if defined (E2_CURRENTGTK_VERSION) && GTK_MINOR_VERSION >= 6
//	if (gtk_check_version (2, 6, 0) == NULL)
	//don't desensitize main window, until we find why the
	//file-chooser show-hidden toggle re-sensitizes the window
		_e2_dialog_show (open_dialog, NULL, E2_DIALOG_RUN);
//	else
//		_e2_dialog_show (open_dialog, app.main_window, E2_DIALOG_RUN);
#else
	_e2_dialog_show (open_dialog, app.main_window, E2_DIALOG_RUN);
#endif
}

==> emelfm2-0.1.4.tar.gz: emelfm2-0.1.4/src/dialogs/e2_select_dir_dialog.c <==
/* $Id: e2_select_dir_dialog.c 1346 2005-10-26 23:26:58Z tpgww $
 * 
 * Copyright (C) 2005 tooar <tooar@gmx.net>
 * 
 * This file is part of emelFM2.
 * emelFM2 is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2, or (at your option)
 * any later version.
 *
 * emelFM2 is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with emelFM2; see the file GPL. If not, contact the Free Software
 * Foundation, 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 */

#include "emelfm2.h"
#include "e2_dialog.h"

static GtkFileChooser *fchooser;
static gchar **choice;

static void _e2_opendir_dialog_ok_cb (GtkWidget *button, GtkWidget *open_dialog)
{
	gchar *dir = gtk_file_chooser_get_current_folder (fchooser);
	if (dir == NULL)
		*choice = NULL;
	else
	{
		gchar *utf = F_FILENAME_FROM_LOCALE (dir);
		*choice = g_strconcat (utf, G_DIR_SEPARATOR_S, NULL);
		g_free (dir);
		F_FREE (utf);
	}
	gtk_widget_destroy (open_dialog);
	open_dialog = NULL;
}
static void _e2_opendir_dialog_cancel_cb (GtkWidget *button, GtkWidget *open_dialog)
{
//	*choice = NULL;
	gtk_widget_destroy (open_dialog);
	open_dialog = NULL;
}

#if defined (E2_CURRENTGTK_VERSION) && GTK_MINOR_VERSION >= 6
//FIXME for some reason, toggling re-sensitizes the main window
static void _e2_opendir_toggle_hodden_cb (GtkWidget *button, GtkFileChooser *fchooser)
{
	gboolean nowhidden = gtk_file_chooser_get_show_hidden (fchooser);
	gtk_file_chooser_set_show_hidden (fchooser, ! nowhidden);
/* FIXME this does not change the button image
	if (nowhidden)
	{
		static GtkWidget *show;
		if (show == NULL)
	FIXME get the icon dir path
			show = gtk_image_new_from_file ("hidden_show_"E2IP".png");//no error check here
		gtk_button_set_image (GTK_BUTTON (button), show);
	}
	else
	{
		static GtkWidget *noshow;
		if (noshow == NULL)
			noshow = gtk_image_new_from_file ("hidden_noshow_"E2IP".png");
		gtk_button_set_image (GTK_BUTTON (button), noshow);
	}
*/
}
#endif
/**
 * @brief display directory-chooser dialog
 *
 * @a newdir is set to a /-terminated string, newly-allocated,
 * or else NULL, if no or invalid choice is made
 *
 * @param currentdir utf string, path of dir to show in chooser when it opens
 * @param newdir pointer to store for chosen new dir-path
 *
 * @return
 */
void e2_opendir_dialog_create (gchar *currentdir, gchar **newdir)
{
	choice = newdir;

	static GtkWidget *open_dialog;
	//only 1 dialog at a time
	if (open_dialog != NULL)
		gtk_widget_destroy (open_dialog);

	open_dialog = gtk_dialog_new ();
	E2_DIALOG_TITLE (GTK_WINDOW (open_dialog), _("open"));

	GtkWidget *vbox = GTK_DIALOG (open_dialog)->vbox;
	gtk_container_set_border_width (GTK_CONTAINER (vbox), E2_PADDING);
	
	GtkWidget *chooser = gtk_file_chooser_widget_new
		(GTK_FILE_CHOOSER_ACTION_SELECT_FOLDER);
	gtk_box_pack_start (GTK_BOX(vbox), chooser, TRUE, TRUE, 0);

//	gtk_file_chooser_set_local_only (FALSE); FIXME vfs
/*	if (g_str_has_suffix (currentdir, G_DIR_SEPARATOR_S)
	{
		gchar *p = currentdir + strlen (currendir);
		*(p-1) = '\0';
	}
*/
	fchooser = GTK_FILE_CHOOSER (chooser);
	gtk_file_chooser_set_current_folder (fchooser, currentdir); //trailing / ok

#if defined (E2_CURRENTGTK_VERSION) && GTK_MINOR_VERSION >= 6
//	if (gtk_check_version (2, 6, 0) == NULL)
//	{
		e2_dialog_add_undefined_button_custom (open_dialog, FALSE, E2_RESPONSE_USER1,
		_("_Hidden"), "hidden_show_"E2IP".png", _("Toggle display of hidden directories"), 
		_e2_opendir_toggle_hodden_cb, fchooser);
//	}
#endif
	e2_dialog_add_button_custom (open_dialog, TRUE, &E2_BUTTON_CANCEL,
		NULL, _e2_opendir_dialog_cancel_cb, open_dialog);
//	GtkWidget *button = e2_dialog_add_defined_button (open_dialog, &E2_BUTTON_CANCEL);
	e2_dialog_add_button_custom (open_dialog, FALSE, &E2_BUTTON_OK,
		NULL, _e2_opendir_dialog_ok_cb, open_dialog);

	e2_dialog_setup (open_dialog, app.main_window);
//	gtk_widget_grab_focus (button);
	e2_dialog_resize (open_dialog, 1.6);

#if defined (E2_CURRENTGTK_VERSION) && GTK_MINOR_VERSION >= 6
//	if (gtk_check_version (2, 6, 0) == NULL)
	//don't desensitize main window, until we find why the
	//file-chooser show-hidden toggle re-sensitizes the window
		_e2_dialog_show (open_dialog, NULL, E2_DIALOG_RUN);
//	else
//		_e2_dialog_show (open_dialog, app.main_window, E2_DIALOG_RUN);
#else
	_e2_dialog_show (open_dialog, app.main_window, E2_DIALOG_RUN);
#endif
}
